# Generated by Django 3.2.25 on 2024-11-06 14:58

from datetime import datetime, time
from django.db import migrations, models
from django.utils import timezone


def populate_new_fields(apps, schema_editor):
    Leihe = apps.get_model("ausleihe", "Leihe")
    db_alias = schema_editor.connection.alias


    for l in Leihe.objects.all():
        l.anfang_neu = timezone.make_aware(datetime.combine(l.anfang, time.min))
        l.ende_neu = timezone.make_aware(datetime.combine(l.ende, time.max))
        l.save()


def populate_old_fields(apps, schema_editor):
    Leihe = apps.get_model("ausleihe", "Leihe")
    db_alias = schema_editor.connection.alias

    for l in Leihe.objects.all():
        l.anfang = l.anfang_neu.date()
        l.ende = l.ende_neu.date()
        l.save()


class Migration(migrations.Migration):

    dependencies = [
        ('ausleihe', '0021_alter_reservierung_options'),
    ]

    operations = [
        # die alten Felder dürfen jetzt NULL sein für die Reversibilität:
        migrations.AlterField(
            model_name='leihe',
            name='anfang',
            field=models.DateField(auto_now=True, null=True),
        ),
        migrations.AlterField(
            model_name='leihe',
            name='ende',
            field=models.DateField(null=True),
        ),
        # neue Felder hinzufügen:
        migrations.AddField(
            model_name='leihe',
            name='anfang_neu',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='leihe',
            name='ende_neu',
            field=models.DateTimeField(null=True),
        ),
        # neue Felder befüllen:
        migrations.RunPython(
            populate_new_fields,
            populate_old_fields,
        ),
        # alte Felder entfernen
        migrations.RemoveField(
            model_name='leihe',
            name='anfang',
        ),
        migrations.RemoveField(
            model_name='leihe',
            name='ende',
        ),
        # neue Felder umbenennen:
        migrations.RenameField(
            model_name='leihe',
            old_name='anfang_neu',
            new_name='anfang',
        ),
        migrations.RenameField(
            model_name='leihe',
            old_name='ende_neu',
            new_name='ende',
        ),
        # neue Felder umdefinieren, sie dürfen jetzt nicht mehr NULL sein:
        migrations.AlterField(
            model_name='leihe',
            name='anfang',
            field=models.DateTimeField(auto_now=True, null=False),
        ),
        migrations.AlterField(
            model_name='leihe',
            name='ende',
            field=models.DateTimeField(null=False),
        ),
    ]
